error API documentation

# error

class IncorrectApiUsageError(builtins.Exception):

Common base class for all non-exit exceptions.

class UrlError(builtins.Exception):

Common base class for all non-exit exceptions.

class MysqlError(builtins.Exception):

Common base class for all non-exit exceptions.

class ConnectionClosedError(builtins.Exception):

Common base class for all non-exit exceptions.

class TransactionClosedError(builtins.Exception):

Common base class for all non-exit exceptions.

class BuilderConsumedError(builtins.Exception):

Common base class for all non-exit exceptions.

class DecodeError(builtins.Exception):

Common base class for all non-exit exceptions.